"""
Django settings for demo project.

Generated by 'django-admin startproject' using Django 3.0.2.

For more information on this file, see
https://docs.djangoproject.com/en/3.0/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/3.0/ref/settings/
"""

import os

from DjangoAppCenter.settings.loader import get_default_database, load_settings_from_file

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))

# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/3.0/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = '5c91=)d#)!!flh93z@w0go5qk1&ao3@nbe9&t!$$n^e5=_-h8j'

# SECURITY WARNING: don't run with debug turned on in production!
dac_environ = os.environ.get("DAC_ENVIRON", "DEV")
DEBUG = True if dac_environ == "DEV" else False

ALLOWED_HOSTS = ["*"]

# Application definition
INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'DjangoAppCenter.packages'
]

# 跨域设置
CORS_ORIGIN_ALLOW_ALL = True
CORS_ALLOW_CREDENTIALS = True

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'corsheaders.middleware.CorsMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

ROOT_URLCONF = 'DjangoAppCenter.settings.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'DjangoAppCenter.wsgi.application'

# Database
# https://docs.djangoproject.com/en/3.0/ref/settings/#databases

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': os.path.join(BASE_DIR, 'db.default.sqlite3'),
    }
}
DATABASE_ROUTERS = ["DjangoAppCenter.settings.dbrouters.Router"],
# Password validation
# https://docs.djangoproject.com/en/3.0/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator',
    },
]

# Internationalization
# https://docs.djangoproject.com/en/3.0/topics/i18n/

LANGUAGE_CODE = 'en-us'

TIME_ZONE = 'UTC'

USE_I18N = True

USE_L10N = True

USE_TZ = True

# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/3.0/howto/static-files/

STATIC_URL = '/static/'
STATIC_ROOT = "statics"
MEDIA_URL = "/media/"
MEDIA_ROOT = "uploads"
ADMIN_SITE_TITLE = "DjangoAppCenter"
ADMIN_SITE_HEADER = "DjangoAppCenter"

# DjangoAppCenter Settings
# DAC_ROUTERS = [
#     {
#         "path": "app/",
#         "urls_module": "app.urls"
#     }
# ]

DAC_ENVIRON = "DEBUG"

DAC_SERVED_HOSTS = "0.0.0.0"

# Global settings overrider
settings = load_settings_from_file()
settings.get("DATABASES", {}).update(**get_default_database())
globals()['DATABASES'].update(**get_default_database())

for key, value in settings.items():
    if isinstance(value, (list, tuple)):
        if key.startswith("_"):
            globals().update(**{key[1:]: value + globals().get(key[1:], [])})
        elif key.endswith("_"):
            globals().update(**{key[:-1]: globals().get(key[:-1], []) + value})
        else:
            globals().update(**{key: value})
    else:
        globals().update(**{key: value})
globals()
